import Ogma from '@linkurious/ogma';

// Create an instance of Ogma
const ogma = new Ogma({
  container: 'graph-container'
});

fetch('cars.csv')
  .then(response => response.text())
  .then(parseCSV)
  .then(graph => ogma.setGraph(graph))
  .then(() => ogma.layouts.force())
  .then(() => ogma.view.locateGraph());

function processCsvLine(graph, line) {
  // Create the person
  graph.nodes.push({
    id: line.person_id,
    data: {
      type: 'Person',
      // eslint-disable-next-line @typescript-eslint/camelcase
      first_name: line.first_name,
      // eslint-disable-next-line @typescript-eslint/camelcase
      last_name: line.last_name,
      email: line.email,
      gender: line.gender
    }
  });

  // Create the Car Maker
  graph.nodes.push({
    id: line.car_maker,
    data: {
      type: 'Maker',
      name: line.car_maker
    }
  });

  // Create the relation
  graph.edges.push({
    id: line.person_id + '-' + line.car_maker,
    source: line.person_id,
    target: line.car_maker,
    data: {
      type: 'Owns'
    }
  });
}

function parseCSV(csvData) {
  return new Promise(function (resolve) {
    const graph = { nodes: [], edges: [] };

    Papa.parse(csvData, {
      worker: true,
      header: true,
      download: false,
      skipEmptyLines: true,
      step: results => {
        console.log(results);
        processCsvLine(graph, results.data);
      },
      complete: () => {
        console.log('CSV import done');
        resolve(graph);
      }
    });
  });
}

// Some styling rules
ogma.styles.addNodeRule({
  color: ogma.rules.map({
    field: 'type',
    values: {
      Person: 'orange',
      Maker: 'purple'
    }
  })
});

// Display the name of the node on hover
ogma.styles.setHoveredNodeAttributes({
  text: node => {
    if (node.getData('type') === 'Person') {
      return node.getData('first_name') + ' ' + node.getData('last_name');
    } else {
      return node.getData('name');
    }
  }
});
